==> easy_ads-1.3.2.tar.gz: lib/rewarded_video_ad/easy_rewarded_video_ad.dart <==
import 'package:firebase_admob/firebase_admob.dart';

import '../easy_ads.dart';

class EasyRewardedVideoAd {
  /// ```
  /// Android: 'ca-app-pub-3940256099942544/5224354917'
  ///
  /// IOS: 'ca-app-pub-3940256099942544/1712485313'
  /// ```
  static final String testAdUnitId = RewardedVideoAd.testAdUnitId;

  /// You have to define this with: RewardedVideoAd.instance
  RewardedVideoAd _rewardedVideoAd;

  /// If not given as an Argument, then EasyAds.defaultTargetingInfo will be used
  MobileAdTargetingInfo targetingInfo;

  /// By default the EasyRewardedVideoAd.testAdUnitId is used.
  String adUnitID;

  /// Turns true when the RewardedVideoAdEvent.loaded is triggered.
  bool _adLoaded;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdLoaded event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLoadedFunction onAdLoaded;

  /// Amount of times the RewardedVideoAdEvent.loaded triggered
  int _loadedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdOpened event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdOpenedFunction onAdOpened;

  /// Amount of times the RewardedVideoAdEvent.opened triggered
  int _openedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdStarted event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdStartedFunction onAdStarted;

  /// Amount of times the RewardedVideoAdEvent.started triggered
  int _startedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdRewarded event.
  ///
  /// ## Parameters
  ///
  /// * int rewardedAmount
  /// * String rewardedType
  AdRewardedFunction onAdRewarded;

  ///Amount of times the RewardedVideoAdEvent.rewarded triggered
  int _rewardedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdCompleted event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdCompletedFunction onAdCompleted;

  /// Amount of times the RewardedVideoAdEvent.completed triggered
  int _completedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdClosed event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdClosedFunction onAdClosed;

  /// Amount of times the RewardedVideoAdEvent.closed triggered
  int _closedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the LeftApplication event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLeftApplicationFunction onLeftApplication;

  /// Amount of times the RewardedVideoAdEvent.leftApplication triggered
  int _leftApplicationCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdFailedToLoad event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdFailedToLoadFunction onAdFailedToLoad;

  /// Amount of times the RewardedVideoAdEvent.failedToLoad triggered
  int _failedToLoadCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on every event.
  ///
  /// ## Parameters
  ///
  /// * String event
  VideoAdEventTriggeredFunction onAdEvent;

  /// ## Description
  ///
  /// * You `have to` call [EasyAds.initialize], otherwise this class will not work.
  ///
  ///
  /// * The [load] method is called in the constructor.
  ///
  ///
  /// * This Ad will automatically be reloaded.
  ///
  /// ## Example
  ///
  /// {@tool sample}
  /// ```
  /// class MyAdWidget extends StatefulWidget {
  ///   @override
  ///   _MyAdWidgetState createState() => _MyAdWidgetState();
  /// }
  ///
  /// class _MyAdWidgetState extends State<MyAdWidget> {
  ///   EasyRewardedVideoAd myTestAd;
  ///
  ///   @override
  ///   void initState() {
  ///     super.initState();
  ///     myTestAd = EasyRewardedVideoAd();
  ///   }
  ///
  ///   @override
  ///   Widget build(BuildContext context) {
  ///     return Scaffold(
  ///       body: Container(
  ///         child: Center(
  ///           child: RaisedButton(onPressed: myTestAd.show),
  ///         ),
  ///       ),
  ///     );
  ///   }
  /// }
  ///
  /// ```
  /// {@end-tool}
  EasyRewardedVideoAd({
    this.targetingInfo,
    this.adUnitID,
    this.onAdLoaded,
    this.onAdOpened,
    this.onAdStarted,
    this.onAdRewarded,
    this.onAdCompleted,
    this.onAdClosed,
    this.onLeftApplication,
    this.onAdFailedToLoad,
    this.onAdEvent,
  }) {
    _rewardedVideoAd = RewardedVideoAd.instance;
    _initValues();
    _initAdListener();
    load();
  }

  void _initValues() {
    adUnitID = adUnitID ?? EasyRewardedVideoAd.testAdUnitId;
    targetingInfo = targetingInfo ?? EasyAds.defaultTargetingInfo;
    _adLoaded = false;

    _loadedCount = 0;
    _openedCount = 0;
    _startedCount = 0;
    _rewardedCount = 0;
    _completedCount = 0;
    _closedCount = 0;
    _leftApplicationCount = 0;
    _failedToLoadCount = 0;
  }

  void _initAdListener() {
    _rewardedVideoAd.listener =
        (RewardedVideoAdEvent event, {String rewardType, int rewardAmount}) {
      switch (event) {
        case RewardedVideoAdEvent.loaded:
          _loadedCount++;
          _adLoaded = true;
          if (onAdLoaded != null) onAdLoaded();
          break;

        case RewardedVideoAdEvent.opened:
          _openedCount++;
          if (onAdOpened != null) onAdOpened();
          break;

        case RewardedVideoAdEvent.started:
          _startedCount++;
          if (onAdStarted != null) onAdStarted();
          break;

        case RewardedVideoAdEvent.rewarded:
          _rewardedCount++;
          if (onAdRewarded != null) onAdRewarded(rewardAmount, rewardType);
          break;

        case RewardedVideoAdEvent.completed:
          _completedCount++;
          if (onAdCompleted != null) onAdCompleted();
          break;

        case RewardedVideoAdEvent.closed:
          _closedCount++;
          load();
          if (onAdClosed != null) onAdClosed();
          break;

        case RewardedVideoAdEvent.leftApplication:
          _leftApplicationCount++;
          load();
          if (onLeftApplication != null) onLeftApplication();
          break;

        case RewardedVideoAdEvent.failedToLoad:
          _failedToLoadCount++;
          load();
          if (onAdFailedToLoad != null) onAdFailedToLoad();
          break;

        default:
          if (onAdEvent != null) onAdEvent(event);
      }
    };
  }

  /// Only shows the RewardedVideoAd if it has been loaded.
  Future<bool> show() {
    if (_adLoaded) {
      _adLoaded = false;
      return _rewardedVideoAd.show();
    }
    return null;
  }

  /// ## Description
  ///
  /// * This method is called in the constructor
  ///
  ///
  /// * Loads Ad, this method is automatically called in the default Listener on the appropriate events.
  Future<bool> load({MobileAdTargetingInfo mobileAdtargetingInfo}) =>
      _rewardedVideoAd.load(
        adUnitId: adUnitID,
        targetingInfo: mobileAdtargetingInfo ?? targetingInfo,
      );

  bool get isLoaded => _adLoaded;

  /// Sets the user id to be used in server-to-server reward callbacks.
  void setUserId(String userId) {
    _rewardedVideoAd.userId = userId;
  }

  /// Sets custom data to be included in server-to-server reward callbacks.
  void setCustomData(String customData) {
    _rewardedVideoAd.customData = customData;
  }

  ///The user id used in server-to-server reward callbacks
  String get userId => _rewardedVideoAd.userId;

  /// Get the RewardedVideoAd instance from the `firebase_admob` library
  RewardedVideoAd get rewardedVideoAd => _rewardedVideoAd;

  ///returns:
  ///```
  ///Ad_Type.VIDEO
  ///```
  Ad_Type get adType => Ad_Type.VIDEO;

  /// * Amount of times the RewardedVideoAdEvent.loaded triggered.
  ///
  ///
  /// * Before `onAdLoaded` is called `loadedCount++` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get loadedCount => _loadedCount;

  /// * Amount of times the RewardedVideoAdEvent.opened triggered.
  ///
  ///
  /// * Before `onAdOpened` is called `openedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get openedCount => _openedCount;

  /// * Amount of times the RewardedVideoAdEvent.started triggered.
  ///
  ///
  /// * Before `onAdStarted` is called `startedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get startedCount => _startedCount;

  /// * Amount of times the RewardedVideoAdEvent.rewarded triggered.
  ///
  ///
  /// * Before `onAdRewarded` is called `rewardedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get rewardedCount => _rewardedCount;

  /// * Amount of times the RewardedVideoAdEvent.completed triggered.
  ///
  ///
  /// * Before `onAdCompleted` is called `completedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get completedCount => _completedCount;

  /// * Amount of times the RewardedVideoAdEvent.closed triggered.
  ///
  ///
  /// * Before `onAdClosed` is called `closedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get closedCount => _closedCount;

  /// * Amount of times the RewardedVideoAdEvent.leftApplication triggered.
  ///
  ///
  /// * Before `onLeftApplication` is called `leftApplicationCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get leftApplicationCount => _leftApplicationCount;

  /// * Amount of times the RewardedVideoAdEvent.failedToLoad triggered.
  ///
  ///
  /// * Before `onAdFailedToLoad` is called `failedToLoadCount++` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get failedToLoadCount => _failedToLoadCount;
}

==> easy_ads-2.0.0.tar.gz: lib/rewarded_video_ad/easy_rewarded_video_ad.dart <==
import 'package:firebase_admob/firebase_admob.dart';

import '../easy_ads.dart';

class EasyRewardedVideoAd {
  /// ```
  /// Android: 'ca-app-pub-3940256099942544/5224354917'
  ///
  /// IOS: 'ca-app-pub-3940256099942544/1712485313'
  /// ```
  static final String testAdUnitId = RewardedVideoAd.testAdUnitId;

  /// You have to define this with: RewardedVideoAd.instance
  RewardedVideoAd _rewardedVideoAd;

  /// If not given as an Argument, then EasyAds.defaultTargetingInfo will be used
  MobileAdTargetingInfo targetingInfo;

  /// By default the EasyRewardedVideoAd.testAdUnitId is used.
  String adUnitId;

  /// Turns true when the RewardedVideoAdEvent.loaded is triggered.
  bool _adLoaded;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdLoaded event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLoadedFunction onAdLoaded;

  /// Amount of times the RewardedVideoAdEvent.loaded triggered
  int _loadedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdOpened event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdOpenedFunction onAdOpened;

  /// Amount of times the RewardedVideoAdEvent.opened triggered
  int _openedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdStarted event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdStartedFunction onAdStarted;

  /// Amount of times the RewardedVideoAdEvent.started triggered
  int _startedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdRewarded event.
  ///
  /// ## Parameters
  ///
  /// * int rewardedAmount
  /// * String rewardedType
  AdRewardedFunction onAdRewarded;

  ///Amount of times the RewardedVideoAdEvent.rewarded triggered
  int _rewardedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdCompleted event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdCompletedFunction onAdCompleted;

  /// Amount of times the RewardedVideoAdEvent.completed triggered
  int _completedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdClosed event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdClosedFunction onAdClosed;

  /// Amount of times the RewardedVideoAdEvent.closed triggered
  int _closedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the LeftApplication event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLeftApplicationFunction onLeftApplication;

  /// Amount of times the RewardedVideoAdEvent.leftApplication triggered
  int _leftApplicationCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdFailedToLoad event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdFailedToLoadFunction onAdFailedToLoad;

  /// Amount of times the RewardedVideoAdEvent.failedToLoad triggered
  int _failedToLoadCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on every event.
  ///
  /// ## Parameters
  ///
  /// * String event
  VideoAdEventTriggeredFunction onAdEvent;

  /// ## Description
  ///
  /// * You `have to` call [EasyAds.initialize], otherwise this class will not work.
  ///
  ///
  /// * The [load] method is called in the constructor.
  ///
  ///
  /// * This Ad will automatically be reloaded.
  ///
  /// ## Example
  ///
  /// {@tool sample}
  /// ```
  /// class MyAdWidget extends StatefulWidget {
  ///   @override
  ///   _MyAdWidgetState createState() => _MyAdWidgetState();
  /// }
  ///
  /// class _MyAdWidgetState extends State<MyAdWidget> {
  ///   EasyRewardedVideoAd myTestAd;
  ///
  ///   @override
  ///   void initState() {
  ///     super.initState();
  ///     myTestAd = EasyRewardedVideoAd();
  ///   }
  ///
  ///   @override
  ///   Widget build(BuildContext context) {
  ///     return Scaffold(
  ///       body: Container(
  ///         child: Center(
  ///           child: RaisedButton(onPressed: myTestAd.show),
  ///         ),
  ///       ),
  ///     );
  ///   }
  /// }
  ///
  /// ```
  /// {@end-tool}
  EasyRewardedVideoAd({
    this.targetingInfo,
    this.adUnitId,
    this.onAdLoaded,
    this.onAdOpened,
    this.onAdStarted,
    this.onAdRewarded,
    this.onAdCompleted,
    this.onAdClosed,
    this.onLeftApplication,
    this.onAdFailedToLoad,
    this.onAdEvent,
  }) {
    _rewardedVideoAd = RewardedVideoAd.instance;
    _initValues();
    _initAdListener();
    load();
  }

  ///returns:
  ///```
  ///AdType.VIDEO
  ///```
  AdType get adType => AdType.VIDEO;

  void _initValues() {
    adUnitId = adUnitId ?? EasyRewardedVideoAd.testAdUnitId;
    targetingInfo = targetingInfo ?? EasyAds.defaultTargetingInfo;
    _adLoaded = false;

    _loadedCount = 0;
    _openedCount = 0;
    _startedCount = 0;
    _rewardedCount = 0;
    _completedCount = 0;
    _closedCount = 0;
    _leftApplicationCount = 0;
    _failedToLoadCount = 0;
  }

  void _initAdListener() {
    _rewardedVideoAd.listener =
        (RewardedVideoAdEvent event, {String rewardType, int rewardAmount}) {
      switch (event) {
        case RewardedVideoAdEvent.loaded:
          _loadedCount++;
          _adLoaded = true;
          if (onAdLoaded != null) onAdLoaded();
          break;

        case RewardedVideoAdEvent.opened:
          _openedCount++;
          if (onAdOpened != null) onAdOpened();
          break;

        case RewardedVideoAdEvent.started:
          _startedCount++;
          if (onAdStarted != null) onAdStarted();
          break;

        case RewardedVideoAdEvent.rewarded:
          _rewardedCount++;
          if (onAdRewarded != null) onAdRewarded(rewardAmount, rewardType);
          break;

        case RewardedVideoAdEvent.completed:
          _completedCount++;
          if (onAdCompleted != null) onAdCompleted();
          break;

        case RewardedVideoAdEvent.closed:
          _closedCount++;
          load();
          if (onAdClosed != null) onAdClosed();
          break;

        case RewardedVideoAdEvent.leftApplication:
          _leftApplicationCount++;
          load();
          if (onLeftApplication != null) onLeftApplication();
          break;

        case RewardedVideoAdEvent.failedToLoad:
          _failedToLoadCount++;
          load();
          if (onAdFailedToLoad != null) onAdFailedToLoad();
          break;

        default:
          if (onAdEvent != null) onAdEvent(event);
      }
    };
  }

  /// Only shows the RewardedVideoAd if it has been loaded.
  Future<bool> show() {
    if (_adLoaded) {
      _adLoaded = false;
      return _rewardedVideoAd.show();
    }
    return null;
  }

  /// ## Description
  ///
  /// * This method is called in the constructor
  ///
  ///
  /// * Loads Ad, this method is automatically called in the default Listener on the appropriate events.
  Future<bool> load({MobileAdTargetingInfo mobileAdtargetingInfo}) =>
      _rewardedVideoAd.load(
        adUnitId: adUnitId,
        targetingInfo: mobileAdtargetingInfo ?? targetingInfo,
      );

  bool get isLoaded => _adLoaded;

  /// Sets the user id to be used in server-to-server reward callbacks.
  void setUserId(String userId) {
    _rewardedVideoAd.userId = userId;
  }

  /// Sets custom data to be included in server-to-server reward callbacks.
  void setCustomData(String customData) {
    _rewardedVideoAd.customData = customData;
  }

  ///The user id used in server-to-server reward callbacks
  String get userId => _rewardedVideoAd.userId;

  /// Get the RewardedVideoAd instance from the `firebase_admob` library
  RewardedVideoAd get rewardedVideoAd => _rewardedVideoAd;

  /// * Amount of times the RewardedVideoAdEvent.loaded triggered.
  ///
  ///
  /// * Before `onAdLoaded` is called `loadedCount++` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get loadedCount => _loadedCount;

  /// * Amount of times the RewardedVideoAdEvent.opened triggered.
  ///
  ///
  /// * Before `onAdOpened` is called `openedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get openedCount => _openedCount;

  /// * Amount of times the RewardedVideoAdEvent.started triggered.
  ///
  ///
  /// * Before `onAdStarted` is called `startedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get startedCount => _startedCount;

  /// * Amount of times the RewardedVideoAdEvent.rewarded triggered.
  ///
  ///
  /// * Before `onAdRewarded` is called `rewardedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get rewardedCount => _rewardedCount;

  /// * Amount of times the RewardedVideoAdEvent.completed triggered.
  ///
  ///
  /// * Before `onAdCompleted` is called `completedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get completedCount => _completedCount;

  /// * Amount of times the RewardedVideoAdEvent.closed triggered.
  ///
  ///
  /// * Before `onAdClosed` is called `closedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get closedCount => _closedCount;

  /// * Amount of times the RewardedVideoAdEvent.leftApplication triggered.
  ///
  ///
  /// * Before `onLeftApplication` is called `leftApplicationCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get leftApplicationCount => _leftApplicationCount;

  /// * Amount of times the RewardedVideoAdEvent.failedToLoad triggered.
  ///
  ///
  /// * Before `onAdFailedToLoad` is called `failedToLoadCount++` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get failedToLoadCount => _failedToLoadCount;
}
